==> webpdf-wsclient-9.0.2-sources.jar: net/webpdf/wsclient/schema/operation/SecurityType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p296078_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:p595873_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;The security operation element can be used to encrypt and decrypt documents.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for SecurityType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="SecurityType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseToolboxType">
 *       <choice>
 *         <element name="decrypt" type="{http://schema.webpdf.de/1.0/operation}DecryptType" minOccurs="0"/>
 *         <element name="encrypt" type="{http://schema.webpdf.de/1.0/operation}EncryptType" minOccurs="0"/>
 *         <element name="encryptCertificate" type="{http://schema.webpdf.de/1.0/operation}EncryptCertificateType" minOccurs="0"/>
 *       </choice>
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SecurityType", propOrder = {
    "decrypt",
    "encrypt",
    "encryptCertificate"
})
public class SecurityType
    extends BaseToolboxType
{

    protected DecryptType decrypt;
    protected EncryptType encrypt;
    protected EncryptCertificateType encryptCertificate;

    /**
     * Gets the value of the decrypt property.
     * 
     * @return
     *     possible object is
     *     {@link DecryptType }
     *     
     */
    public DecryptType getDecrypt() {
        return decrypt;
    }

    /**
     * Sets the value of the decrypt property.
     * 
     * @param value
     *     allowed object is
     *     {@link DecryptType }
     *     
     */
    public void setDecrypt(DecryptType value) {
        this.decrypt = value;
    }

    public boolean isSetDecrypt() {
        return (this.decrypt!= null);
    }

    /**
     * Gets the value of the encrypt property.
     * 
     * @return
     *     possible object is
     *     {@link EncryptType }
     *     
     */
    public EncryptType getEncrypt() {
        return encrypt;
    }

    /**
     * Sets the value of the encrypt property.
     * 
     * @param value
     *     allowed object is
     *     {@link EncryptType }
     *     
     */
    public void setEncrypt(EncryptType value) {
        this.encrypt = value;
    }

    public boolean isSetEncrypt() {
        return (this.encrypt!= null);
    }

    /**
     * Gets the value of the encryptCertificate property.
     * 
     * @return
     *     possible object is
     *     {@link EncryptCertificateType }
     *     
     */
    public EncryptCertificateType getEncryptCertificate() {
        return encryptCertificate;
    }

    /**
     * Sets the value of the encryptCertificate property.
     * 
     * @param value
     *     allowed object is
     *     {@link EncryptCertificateType }
     *     
     */
    public void setEncryptCertificate(EncryptCertificateType value) {
        this.encryptCertificate = value;
    }

    public boolean isSetEncryptCertificate() {
        return (this.encryptCertificate!= null);
    }

}

==> webpdf-wsclient-10.0.0-sources.jar: net/webpdf/wsclient/schema/operation/SecurityType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p54688_="https://jakarta.ee/xml/ns/jaxb" xmlns:p573971_="urn:jaxb.jvnet.org:plugin:inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;The security operation element can be used to encrypt and decrypt documents.&lt;/p&gt;
 * </pre>
 * 
 * <p>Java class for SecurityType complex type</p>.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.</p>
 * 
 * <pre>{@code
 * <complexType name="SecurityType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}BaseToolboxType">
 *       <choice>
 *         <element name="decrypt" type="{http://schema.webpdf.de/1.0/operation}DecryptType" minOccurs="0"/>
 *         <element name="encrypt" type="{http://schema.webpdf.de/1.0/operation}EncryptType" minOccurs="0"/>
 *         <element name="encryptCertificate" type="{http://schema.webpdf.de/1.0/operation}EncryptCertificateType" minOccurs="0"/>
 *       </choice>
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "SecurityType", propOrder = {
    "decrypt",
    "encrypt",
    "encryptCertificate"
})
public class SecurityType
    extends BaseToolboxType
{

    protected DecryptType decrypt;
    protected EncryptType encrypt;
    protected EncryptCertificateType encryptCertificate;

    /**
     * Gets the value of the decrypt property.
     * 
     * @return
     *     possible object is
     *     {@link DecryptType }
     *     
     */
    public DecryptType getDecrypt() {
        return decrypt;
    }

    /**
     * Sets the value of the decrypt property.
     * 
     * @param value
     *     allowed object is
     *     {@link DecryptType }
     *     
     */
    public void setDecrypt(DecryptType value) {
        this.decrypt = value;
    }

    public boolean isSetDecrypt() {
        return (this.decrypt!= null);
    }

    /**
     * Gets the value of the encrypt property.
     * 
     * @return
     *     possible object is
     *     {@link EncryptType }
     *     
     */
    public EncryptType getEncrypt() {
        return encrypt;
    }

    /**
     * Sets the value of the encrypt property.
     * 
     * @param value
     *     allowed object is
     *     {@link EncryptType }
     *     
     */
    public void setEncrypt(EncryptType value) {
        this.encrypt = value;
    }

    public boolean isSetEncrypt() {
        return (this.encrypt!= null);
    }

    /**
     * Gets the value of the encryptCertificate property.
     * 
     * @return
     *     possible object is
     *     {@link EncryptCertificateType }
     *     
     */
    public EncryptCertificateType getEncryptCertificate() {
        return encryptCertificate;
    }

    /**
     * Sets the value of the encryptCertificate property.
     * 
     * @param value
     *     allowed object is
     *     {@link EncryptCertificateType }
     *     
     */
    public void setEncryptCertificate(EncryptCertificateType value) {
        this.encryptCertificate = value;
    }

    public boolean isSetEncryptCertificate() {
        return (this.encryptCertificate!= null);
    }

}
